import { Module } from '@nuxt/types';
import Vue from 'vue';

/**
 * The WebSocketManager class that defines methods for WebSocket interaction.
 */
declare class WebSocketManager {
    url: string;
    emitter: Vue;
    reconnectInterval: number;
    ws: WebSocket;
    /**
     * Constructor function for the WebSocketManager class.
     * Initializes properties and invokes connect method.
     *
     * @param {string} url The WebSocket URL to connect.
     * @param {number} reconnectInterval Time in ms to reconnect.
     * @returns {WebSocketManager} The WebSocketManager instance.
     */
    constructor(url: string, emitter: Vue, reconnectInterval: number);
    /**
     * Establishes WebSocket connection.
     * Defines handlers for message, close and error events.
     *
     * @returns {void} Returns with no return value once the connection is established.
     */
    connect(): void;
    /**
     * Ensures the WebSocket connection is open.
     *
     * @returns {Promise<void>} A promise that resolves with no return value straightaway if the WebSocket connection is open.
     * Or else, waits until the open event is fired.
     */
    ready(): Promise<void>;
    /**
     * Waits for the WebSocket connection to be open if not already and transmits the data received.
     *
     * @param {string | Record<string, unknown>} message The data to be transmitted.
     * @returns {Promise<void>} A promise that resolves with no return value on transmitting the data.
     */
    send(message: string | Record<string, unknown>): Promise<void>;
    /**
     * Closes the WebSocket connection.
     *
     * @param {number | undefined} [code] The connection close code.
     * @param {string | undefined} [reason] The connection close reason.
     * @returns {void} Returns with no return value once the connection is closed.
     */
    close(code?: number | undefined, reason?: string | undefined): void;
}

interface ModuleOptions {
    uri: string;
}
declare const websocketModule: Module<ModuleOptions>;
declare module '@nuxt/types' {
    interface NuxtConfig {
        $socket: Vue;
        $socketManager: WebSocketManager;
    }
    interface Configuration {
        $socket: Vue;
        $socketManager: WebSocketManager;
    }
}
declare module 'vue/types/vue' {
    interface Vue {
        $socket: Vue;
        $socketManager: WebSocketManager;
    }
}

export default websocketModule;
export { ModuleOptions };
